@@ -21,8 +21,6 @@
 shinyWidgetsGallery <- function() { # nocov start
   if (!requireNamespace(package = "shinydashboard"))
     message("Package 'shinydashboard' is required to run this function")
-  if (!requireNamespace(package = "formatR"))
-    message("Package 'formatR' is required to run this function")
   shiny::shinyAppDir(system.file('examples/shinyWidgets', package='shinyWidgets', mustWork=TRUE))
 }
 # nocov end
