@@ -78,10 +78,9 @@ validateSelected <- function (selected, choices, inputId)
 }
 
 
-`%AND%` <- function (x, y)
-{
-  if (!is.null(x) && !is.na(x))
-    if (!is.null(y) && !is.na(y))
+`%AND%` <- function (x, y) {
+  if (!is.null(x) && !anyNA(x))
+    if (!is.null(y) && !anyNA(y))
       return(y)
   return(NULL)
 }
@@ -167,4 +166,11 @@ validateIcon <- function (icon)
   }
 }
 
+controlLabel <- function(controlName, label) {
+  label %AND% htmltools::tags$label(class = "control-label", `for` = controlName, label)
+}
 
+formatNoSci <- function(x) {
+  if (is.null(x)) return(NULL)
+  format(x, scientific = FALSE, digits = 15)
+}
