@@ -4,7 +4,7 @@
 /* Source: https://bootsnipp.com/snippets/featured/simple-vertical-tab */
 
 $(document).ready(function() {
-    $("div.bhoechie-tab-menu>div.list-group>a").click(function(e) {
+    $("div.bhoechie-tab-menu>div.list-group").on('click', '> *', function(e) {
         e.preventDefault();
         $(this).siblings('a.active').removeClass("active");
         $(this).addClass("active");
